package com.schoolinout.system.service;

import com.schoolinout.system.domain.Student;
import com.schoolinout.system.domain.vo.StudentListVo;

import java.util.List;

/**
 * 学生管理Service接口
 *
 * @author sakura
 * @date 2024-01-03
 */
public interface IStudentService {

    /**
     * 查询全部的学生列表
     *
     * @param student
     * @return
     */
    public List<StudentListVo> listAll(Student student);

    /**
     * 查询学生管理
     *
     * @param id 学生管理主键
     * @return 学生管理
     */
    public Student selectStudentById(Long id);

    /**
     * 查询学生管理列表
     *
     * @param student 学生管理
     * @return 学生管理集合
     */
    public List<Student> selectStudentList(Student student);

    /**
     * 新增学生管理
     *
     * @param student 学生管理
     * @return 结果
     */
    public int insertStudent(Student student);

    /**
     * 修改学生管理
     *
     * @param student 学生管理
     * @return 结果
     */
    public int updateStudent(Student student);

    /**
     * 批量删除学生管理
     *
     * @param ids 需要删除的学生管理主键集合
     * @return 结果
     */
    public int deleteStudentByIds(Long[] ids);

    /**
     * 删除学生管理信息
     *
     * @param id 学生管理主键
     * @return 结果
     */
    public int deleteStudentById(Long id);
}
